==> cxf-testutils-2.0.10.0-fuse-sources.jar: org/apache/type_test/doc/TestChoiceArray.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.ChoiceArray;


/**
 * <p>Java class for testChoiceArray element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testChoiceArray">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}ChoiceArray"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}ChoiceArray"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testChoiceArray")
public class TestChoiceArray {

    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected ChoiceArray x;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected ChoiceArray y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceArray }
     *     
     */
    public ChoiceArray getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceArray }
     *     
     */
    public void setX(ChoiceArray value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceArray }
     *     
     */
    public ChoiceArray getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceArray }
     *     
     */
    public void setY(ChoiceArray value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.18-fuse-sources.jar: org/apache/type_test/doc/TestChoiceArray.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.ChoiceArray;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}ChoiceArray"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}ChoiceArray"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testChoiceArray")
public class TestChoiceArray {

    @XmlElement(required = true)
    protected ChoiceArray x;
    @XmlElement(required = true)
    protected ChoiceArray y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceArray }
     *     
     */
    public ChoiceArray getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceArray }
     *     
     */
    public void setX(ChoiceArray value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceArray }
     *     
     */
    public ChoiceArray getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceArray }
     *     
     */
    public void setY(ChoiceArray value) {
        this.y = value;
    }

}
